==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/FilePump.pm <==
package WebGUI::i18n::German::FilePump;
use utf8;
our $I18N = {
  'Add Bundle' => {
    'lastUpdated' => '1246485803',
    'message' => 'Objektpakete'
  },
  'File Pump' => {
    'lastUpdated' => '1246485745',
    'message' => 'Datei Express'
  },
  'add a bundle' => {
    'lastUpdated' => '1246485847',
    'message' => 'Objektpaket hinzufügen'
  },
  'build' => {
    'lastUpdated' => '1246485874',
    'message' => 'Zusammensetzen'
  },
  'build error' => {
    'lastUpdated' => '1246485899',
    'message' => 'Fehler beim URI: %s'
  },
  'build this bundle' => {
    'lastUpdated' => '1246485941',
    'message' => 'Dieses Paket zusammenstellen'
  },
  'bundle name' => {
    'lastUpdated' => '1246485973',
    'message' => 'Name des Dateipakets'
  },
  'bundle name help' => {
    'lastUpdated' => '1246486006',
    'message' => 'EIn eindeutiger Name für dieses Paket.'
  },
  'cssFiles' => {
    'lastUpdated' => '1246486018',
    'message' => 'CSS'
  },
  'duplicate directory' => {
    'lastUpdated' => '1246486081',
    'message' => 'Es gibt bereits ein Verzeichnis mit gleicher Bezeichnung.'
  },
  'duplicate file' => {
    'lastUpdated' => '1246486121',
    'message' => 'Im Erstellungsverzeichnis gibt es diesen Namen bereits.'
  },
  'jsFiles' => {
    'lastUpdated' => '1246486132',
    'message' => 'JavaScript'
  },
  'last build' => {
    'lastUpdated' => '1246486158',
    'message' => 'Zuletzt erstellt'
  },
  'last modified' => {
    'lastUpdated' => '1246486171',
    'message' => 'Zuletzt modifiziert'
  },
  'list bundles' => {
    'lastUpdated' => '1246486188',
    'message' => 'Pakete auflisten'
  },
  'new bundle' => {
    'lastUpdated' => '1246486202',
    'message' => 'Neues Paket'
  },
  'not yet' => {
    'lastUpdated' => '1246486218',
    'message' => 'Noch nicht'
  },
  'otherFiles' => {
    'lastUpdated' => '1247904760',
    'message' => 'weitere Dateien'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/FilePump.pm <==
package WebGUI::i18n::German::FilePump;
use utf8;
our $I18N = {
  'Add Bundle' => {
    'lastUpdated' => '1246485803',
    'message' => 'Objektpakete'
  },
  'File Pump' => {
    'lastUpdated' => '1246485745',
    'message' => 'Datei Express'
  },
  'add a bundle' => {
    'lastUpdated' => '1246485847',
    'message' => 'Objektpaket hinzufügen'
  },
  'build' => {
    'lastUpdated' => '1246485874',
    'message' => 'Zusammensetzen'
  },
  'build error' => {
    'lastUpdated' => '1246485899',
    'message' => 'Fehler beim URI: %s'
  },
  'build this bundle' => {
    'lastUpdated' => '1246485941',
    'message' => 'Dieses Paket zusammenstellen'
  },
  'bundle name' => {
    'lastUpdated' => '1246485973',
    'message' => 'Name des Dateipakets'
  },
  'bundle name help' => {
    'lastUpdated' => '1277325659',
    'message' => 'Ein eindeutiger Name für dieses Paket.'
  },
  'cssFiles' => {
    'lastUpdated' => '1246486018',
    'message' => 'CSS'
  },
  'duplicate directory' => {
    'lastUpdated' => '1246486081',
    'message' => 'Es gibt bereits ein Verzeichnis mit gleicher Bezeichnung.'
  },
  'duplicate file' => {
    'lastUpdated' => '1246486121',
    'message' => 'Im Erstellungsverzeichnis gibt es diesen Namen bereits.'
  },
  'jsFiles' => {
    'lastUpdated' => '1246486132',
    'message' => 'JavaScript'
  },
  'last build' => {
    'lastUpdated' => '1246486158',
    'message' => 'Zuletzt erstellt'
  },
  'last modified' => {
    'lastUpdated' => '1246486171',
    'message' => 'Zuletzt modifiziert'
  },
  'list bundles' => {
    'lastUpdated' => '1246486188',
    'message' => 'Pakete auflisten'
  },
  'new bundle' => {
    'lastUpdated' => '1246486202',
    'message' => 'Neues Paket'
  },
  'not yet' => {
    'lastUpdated' => '1246486218',
    'message' => 'Noch nicht'
  },
  'otherFiles' => {
    'lastUpdated' => '1247904760',
    'message' => 'weitere Dateien'
  }
}
;

1;
